/*
 * Integer fixed-point lookup trig
 *
 * (c) 2012 Matt Evans
 * Licenced under GPLv2
 */

#ifndef ITRIG_H
#define ITRIG_H

#include <inttypes.h>
#include <avr/pgmspace.h>

#define SINSTEPS	512
extern PROGMEM int16_t sintab[];
#define TWOPI		(SINSTEPS*4)

static inline int16_t isin(uint16_t ang)
{
	/* Units are 360/(512*4) degrees.  Sine table holds 0-90deg,
	 * so angles 90-180 are table[180-ang]
	 * angles 180-270 are -table[ang-180]
	 * angles 270-360 are -table[360-ang]
	 * 360 degrees = 2048 = 0x800
	 */
	ang &= 0x7ff;
	switch (ang & 0x600) {
		case 0x000:
			return pgm_read_word(&sintab[ang]);
			break;
		case 0x200:
			return pgm_read_word(&sintab[0x3ff-ang]);
			break;
		case 0x400:
			return -pgm_read_word(&sintab[ang-0x400]);
			break;
		case 0x600:
			return -pgm_read_word(&sintab[0x7ff-ang]);
			break;
	}
	return 0;
}

static inline int16_t icos(uint16_t ang)
{
	return isin(ang+512); /* cos(x) = sin(x+90) */
}

extern PROGMEM int16_t divtab_a[];
extern PROGMEM int8_t divtab_b[];
/* Not trig but hey..
 * A fastish lookup idiv.
 */
static inline int16_t idiv(int32_t a, int16_t d)
{
	if (d < 0) {
		d = -d;
		a = -a;
	}
	if (d == 0)
		return 0;
	else if (d == 1)
		return a;

	if (d <= 256)
		return (((uint16_t)pgm_read_word(&divtab_a[d-2])) * a)
			>> 16;
	else if (d < 1024)
		return (((uint8_t)pgm_read_byte(&divtab_b[d-257])) * a)
			>> 16;
	else
		return a/d;
}

#endif
