#include "points.h"
#include <avr/pgmspace.h>

/*
 * Simple wireframe likeness to a TIE Interceptor (TM Starwars Lucas etc. etc.).
 * This is not ILM CGI-quality... don't sue me for the fan art. :P
 *
 * The coordinates are specified in units via these macros so can be scaled to
 * anything.  The model is 110x85x95 in XxYxZ and balanced (i.e. has 0,0,0 in
 * its centre).
 */
#define X(x)	(2*(x))
#define Y(y)	(2*(y))
#define Z(z)	(2*(z))

/* About 144 lines here! */

PROGMEM point3d tie[] = {
	/* Right wing */	
	{ TOK_SPECIAL, TOK_LINE_STRIP, 15 },
	{ X(13), Y(10), Z(-47) },
	{ X(-55), Y(10), Z(-47) },
	{ X(-55), Y(13), Z(-47) },
	{ X(-52), Y(13), Z(-47) },
	{ X(18), Y(43), Z(-27) },
	{ X(38), Y(43), Z(-27) },
	{ X(55), Y(13), Z(-47) },
	{ X(55), Y(-12), Z(-47) },
	{ X(38), Y(-42), Z(-27) },
	{ X(18), Y(-42), Z(-27) },
	{ X(-52), Y(-12), Z(-47) },
	{ X(-55), Y(-12), Z(-47) },
	{ X(-55), Y(-9), Z(-47) },
	{ X(13), Y(-9), Z(-47) },
	{ X(13), Y(10), Z(-47) },
	/* Right wing panel A */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(18), Y(16), Z(-45) },
	{ X(-35), Y(16), Z(-45) },
	{ X(18), Y(38), Z(-30.2) },
	{ X(18), Y(16), Z(-45) },
	/* Right wing panel B */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 5 },
	{ X(25), Y(16), Z(-45) },
	{ X(25), Y(38), Z(-30.2) },
	{ X(37), Y(38), Z(-30.2) },
	{ X(49), Y(16), Z(-45) },
	{ X(25), Y(16), Z(-45) },
	/* Right wing panel C */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 5 },
	{ X(25), Y(-15), Z(-45) },
	{ X(49), Y(-15), Z(-45) },
	{ X(37), Y(-37), Z(-30.2) },
	{ X(25), Y(-37), Z(-30.2) },
	{ X(25), Y(-15), Z(-45) },
	/* Right wing panel D */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(17), Y(-15), Z(-45) },
	{ X(17), Y(-37), Z(-30.2) },
	{ X(-35), Y(-15), Z(-45) },
	{ X(17), Y(-15), Z(-45) },

	/* Right wing support arm */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 6 },
	{ X(17), Y(6), Z(-47) },
	{ X(26), Y(6), Z(-47) },
	{ X(26), Y(-5), Z(-47) },
	{ X(17), Y(-5), Z(-47) },
	{ X(17), Y(6), Z(-47) },
	{ X(15), Y(8), Z(-17) },
	{ TOK_SPECIAL, TOK_LINES, 3 },
	{ X(28), Y(8), Z(-17) },
	{ X(26), Y(6), Z(-47) },
	{ X(26), Y(-5), Z(-47) },
	{ X(28), Y(-7), Z(-17) },
	{ X(15), Y(-7), Z(-17) },
	{ X(17), Y(-5), Z(-47) },

	/* Pod top  */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(28), Y(8), Z(-17) },
	{ X(28), Y(18), Z(-7) },
	{ X(28), Y(18), Z(8) },
	{ X(28), Y(8), Z(18) },
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(15), Y(8), Z(18) },
	{ X(15), Y(18), Z(8) },
	{ X(15), Y(18), Z(-7) },
	{ X(15), Y(8), Z(-17) },
	/* Pod bottom  */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(28), Y(-7), Z(-17) },
	{ X(28), Y(-17), Z(-7) },
	{ X(28), Y(-17), Z(8) },
	{ X(28), Y(-7), Z(18) },
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(15), Y(-7), Z(18) },
	{ X(15), Y(-17), Z(8) },
	{ X(15), Y(-17), Z(-7) },
	{ X(15), Y(-7), Z(-17) },
	/* Pod front, wrapping to bottom then top */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 28 },
	{ X(15), Y(-7), Z(-17) },
	{ X(8), Y(-7), Z(-12) },
	{ X(2), Y(-5), Z(-5) },
	{ X(2), Y(-5), Z(6) },
	{ X(8), Y(-7), Z(13) },
	{ X(8), Y(8), Z(13) },
	{ X(2), Y(6), Z(6) },
	{ X(2), Y(6), Z(-5) },
	{ X(8), Y(8), Z(-12) },
	{ X(8), Y(-7), Z(-12) },
	{ X(8), Y(-12), Z(-7) },
	{ X(8), Y(-12), Z(8) },
	{ X(2), Y(-5), Z(6) },
	{ X(2), Y(6), Z(6) },
	{ X(8), Y(13), Z(8) },
	{ X(8), Y(13), Z(-7) },
	{ X(2), Y(6), Z(-5) },
	{ X(2), Y(-5), Z(-5) },
	{ X(8), Y(-12), Z(-7) },
	{ X(15), Y(-17), Z(-7) },/* bottom */
	{ X(28), Y(-17), Z(-7) },
	{ X(38), Y(-7), Z(-7) },
	{ X(38), Y(8), Z(-7) },
	{ X(28), Y(18), Z(-7) },
	{ X(15), Y(18), Z(-7) },
	{ X(8), Y(13), Z(-7) },
	{ X(8), Y(8), Z(-12) },
	{ X(15), Y(8), Z(-17) },
	/* Pod left/bottom/wrapping to top */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 12 },
	{ X(15), Y(-7), Z(18) },
	{ X(8), Y(-7), Z(13) },
	{ X(8), Y(-12), Z(8) },
	{ X(15), Y(-17), Z(8) },/* bottom */
	{ X(28), Y(-17), Z(8) },
	{ X(38), Y(-7), Z(8) },
	{ X(38), Y(8), Z(8) },
	{ X(28), Y(18), Z(8) },
	{ X(15), Y(18), Z(8) },
	{ X(8), Y(13), Z(8) },
	{ X(8), Y(8), Z(13) },
	{ X(15), Y(8), Z(18) },
	/* Pod back */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(28), Y(-7), Z(18) },
	{ X(38), Y(-7), Z(8) },
	{ X(38), Y(-7), Z(-7) },
	{ X(28), Y(-7), Z(-17) },
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(28), Y(8), Z(-17) },
	{ X(38), Y(8), Z(-7) },
	{ X(38), Y(8), Z(8) },
	{ X(28), Y(8), Z(18) },
	/* Done! */
	/* Left wing support arm */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 6 },
	{ X(15), Y(8), Z(18) },
	{ X(17), Y(6), Z(48) },
	{ X(17), Y(-5), Z(48) },
	{ X(26), Y(-5), Z(48) },
	{ X(26), Y(6), Z(48) },
	{ X(17), Y(6), Z(48) },
	{ TOK_SPECIAL, TOK_LINES, 3 },
	{ X(26), Y(6), Z(48) },
	{ X(28), Y(8), Z(18) },
	{ X(28), Y(-7), Z(18) },
	{ X(26), Y(-5), Z(48) },
	{ X(17), Y(-5), Z(48) },
	{ X(15), Y(-7), Z(18) },

	/* Left wing (opp. winding, just copied right wing above..) */	
	{ TOK_SPECIAL, TOK_LINE_STRIP, 15 },
	{ X(13), Y(10), Z(48) },
	{ X(-55), Y(10), Z(48) },
	{ X(-55), Y(13), Z(48) },
	{ X(-52), Y(13), Z(48) },
	{ X(18), Y(43), Z(28) },
	{ X(38), Y(43), Z(28) },
	{ X(55), Y(13), Z(48) },
	{ X(55), Y(-12), Z(48) },
	{ X(38), Y(-42), Z(28) },
	{ X(18), Y(-42), Z(28) },
	{ X(-52), Y(-12), Z(48) },
	{ X(-55), Y(-12), Z(48) },
	{ X(-55), Y(-9), Z(48) },
	{ X(13), Y(-9), Z(48) },
	{ X(13), Y(10), Z(48) },
	/* Left wing panel A */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(18), Y(16), Z(46) },
	{ X(-35), Y(16), Z(46) },
	{ X(18), Y(38), Z(31.2) },
	{ X(18), Y(16), Z(46) },
	/* Left wing panel B */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 5 },
	{ X(25), Y(16), Z(46) },
	{ X(25), Y(38), Z(31.2) },
	{ X(37), Y(38), Z(31.2) },
	{ X(49), Y(16), Z(46) },
	{ X(25), Y(16), Z(46) },
	/* Left wing panel C */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 5 },
	{ X(25), Y(-15), Z(46) },
	{ X(49), Y(-15), Z(46) },
	{ X(37), Y(-37), Z(31.2) },
	{ X(25), Y(-37), Z(31.2) },
	{ X(25), Y(-15), Z(46) },
	/* Left wing panel D */
	{ TOK_SPECIAL, TOK_LINE_STRIP, 4 },
	{ X(17), Y(-15), Z(46) },
	{ X(17), Y(-37), Z(31.2) },
	{ X(-35), Y(-15), Z(46) },
	{ X(17), Y(-15), Z(46) },
	{ TOK_SPECIAL, TOK_END, 0 }
};
